HasValidate

Trait HasValidate 

pub trait HasValidate {
    type Validate;

    // Required method
    fn get_validate(&self) -> &Self::Validate;
}
Trait for types that can supply a reference that can be validated.

Extractor types T that implement this trait can be used with Valid, Garde or Validated.

Required Associated Types

type Validate

Inner type that can be validated for correctness

Required Methods

fn get_validate(&self) -> &Self::Validate

Get the inner value

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T, R> HasValidate for BaseMultipart<T, R>

Source

impl<T, R> HasValidate for WithRejection<T, R>

Source

impl<T> HasValidate for Cached<T>

Source

type Validate = T

Source

fn get_validate(&self) -> &Self::Validate

Source

impl<T> HasValidate for Cbor<T>

Source

impl<T> HasValidate for Form<T>

Source

impl<T> HasValidate for Form<T>

Source

impl<T> HasValidate for Json<T>

Source

impl<T> HasValidate for MsgPack<T>

Source

impl<T> HasValidate for MsgPackRaw<T>

Source

impl<T> HasValidate for Path<T>

Source

impl<T> HasValidate for Protobuf<T>

Source

impl<T> HasValidate for Query<T>

Source

impl<T> HasValidate for Query<T>

Source

impl<T> HasValidate for Sonic<T>

Source

impl<T> HasValidate for Toml<T>

Source

impl<T> HasValidate for TypedHeader<T>

Source

impl<T> HasValidate for TypedMultipart<T>

Source

impl<T> HasValidate for Xml<T>

Source

impl<T> HasValidate for Yaml<T>

Implementors